diff --git a/core/modules/rdf/lib/Drupal/rdf/Tests/TrackerAttributesTest.php b/core/modules/rdf/lib/Drupal/rdf/Tests/TrackerAttributesTest.php
index b4a4082..d97924f 100644
--- a/core/modules/rdf/lib/Drupal/rdf/Tests/TrackerAttributesTest.php
+++ b/core/modules/rdf/lib/Drupal/rdf/Tests/TrackerAttributesTest.php
@@ -128,7 +128,7 @@ function _testBasicTrackerRdfaMarkup(EntityInterface $node) {
     // Parses tracker page where the nodes are displayed in a table.
     $parser = new \EasyRdf_Parser_Rdfa();
     $graph = new \EasyRdf_Graph();
-    $parser->parse($graph, $this->drupalGet('tracker'), 'rdfa', $this->base_uri);
+    $parser->parse($graph, $this->drupalGet('activity'), 'rdfa', $this->base_uri);
 
     // Inspects RDF graph output.
     // Node title.
@@ -177,7 +177,7 @@ function _testBasicTrackerRdfaMarkup(EntityInterface $node) {
     // Parses tracker page where the nodes are displayed in a table.
     $parser = new \EasyRdf_Parser_Rdfa();
     $graph = new \EasyRdf_Graph();
-    $parser->parse($graph, $this->drupalGet('tracker'), 'rdfa', $this->base_uri);
+    $parser->parse($graph, $this->drupalGet('activity'), 'rdfa', $this->base_uri);
 
     // Number of comments.
     $expected_value = array(
diff --git a/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerTest.php b/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerTest.php
index 7a3983e..3fe9e52 100644
--- a/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerTest.php
+++ b/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerTest.php
@@ -69,14 +69,14 @@ function testTrackerAll() {
       'status' => 1,
     ));
 
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertNoText($unpublished->label(), 'Unpublished node do not show up in the tracker listing.');
     $this->assertText($published->label(), 'Published node show up in the tracker listing.');
     $this->assertLink(t('My recent content'), 0, 'User tab shows up on the global tracker page.');
 
     // Delete a node and ensure it no longer appears on the tracker.
     $published->delete();
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertNoText($published->label(), 'Deleted node do not show up in the tracker listing.');
   }
 
@@ -112,7 +112,7 @@ function testTrackerUser() {
     );
     $this->drupalPostForm('comment/reply/node/' . $other_published_my_comment->id() . '/comment', $comment, t('Save'));
 
-    $this->drupalGet('user/' . $this->user->id() . '/track');
+    $this->drupalGet('user/' . $this->user->id() . '/activity');
     $this->assertNoText($unpublished->label(), "Unpublished nodes do not show up in the users's tracker listing.");
     $this->assertText($my_published->label(), "Published nodes show up in the user's tracker listing.");
     $this->assertNoText($other_published_no_comment->label(), "Other user's nodes do not show up in the user's tracker listing.");
@@ -122,7 +122,7 @@ function testTrackerUser() {
     $admin_user = $this->drupalCreateUser(array('post comments', 'administer comments', 'access user profiles'));
     $this->drupalLogin($admin_user);
     $this->drupalPostForm('comment/1/edit', array('status' => COMMENT_NOT_PUBLISHED), t('Save'));
-    $this->drupalGet('user/' . $this->user->id() . '/track');
+    $this->drupalGet('user/' . $this->user->id() . '/activity');
     $this->assertNoText($other_published_my_comment->label(), 'Unpublished comments are not counted on the tracker listing.');
   }
 
@@ -138,7 +138,7 @@ function testTrackerNewNodes() {
 
     $node = $this->drupalCreateNode($edit);
     $title = $edit['title'];
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertPattern('/' . $title . '.*new/', 'New nodes are flagged as such in the tracker listing.');
 
     $this->drupalGet('node/' . $node->id());
@@ -150,11 +150,11 @@ function testTrackerNewNodes() {
         'Accept: application/json',
       ),
     ));
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertNoPattern('/' . $title . '.*new/', 'Visited nodes are not flagged as new.');
 
     $this->drupalLogin($this->other_user);
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertPattern('/' . $title . '.*new/', 'For another user, new nodes are flagged as such in the tracker listing.');
 
     $this->drupalGet('node/' . $node->id());
@@ -166,7 +166,7 @@ function testTrackerNewNodes() {
         'Accept: application/json',
       ),
     ));
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertNoPattern('/' . $title . '.*new/', 'For another user, visited nodes are not flagged as new.');
   }
 
@@ -197,7 +197,7 @@ function testTrackerNewComments() {
     ));
 
     $this->drupalLogin($this->other_user);
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertText('1 new', 'New comments are counted on the tracker listing pages.');
     $this->drupalGet('node/' . $node->id());
 
@@ -212,7 +212,7 @@ function testTrackerNewComments() {
     $this->drupalPostForm('comment/reply/node/' . $node->id(). '/comment', $comment, t('Save'));
 
     $this->drupalLogin($this->user);
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertText('1 new', 'New comments are counted on the tracker listing pages.');
   }
 
@@ -253,7 +253,7 @@ function testTrackerCronIndexing() {
     $this->drupalLogin($this->user);
 
     // Fetch the user's tracker.
-    $this->drupalGet('tracker/' . $this->user->id());
+    $this->drupalGet('activity/' . $this->user->id());
 
     // Assert that all node titles are displayed.
     foreach ($nodes as $i => $node) {
@@ -263,7 +263,7 @@ function testTrackerCronIndexing() {
     $this->assertText('updated', 'Node is listed as updated');
 
     // Fetch the site-wide tracker.
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
 
     // Assert that all node titles are displayed.
     foreach ($nodes as $i => $node) {
@@ -285,7 +285,7 @@ function testTrackerAdminUnpublish() {
     ));
 
     // Assert that the node is displayed.
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertText($node->label(), 'Node is displayed on the tracker listing pages.');
 
     // Unpublish the node and ensure that it's no longer displayed.
@@ -295,7 +295,7 @@ function testTrackerAdminUnpublish() {
     );
     $this->drupalPostForm('admin/content', $edit, t('Apply'));
 
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertText(t('No content available.'), 'Node is displayed on the tracker listing pages.');
   }
 }
diff --git a/core/modules/tracker/tracker.module b/core/modules/tracker/tracker.module
index 878a755..255afd8 100644
--- a/core/modules/tracker/tracker.module
+++ b/core/modules/tracker/tracker.module
@@ -22,9 +22,9 @@ function tracker_help($path, $arg) {
       $output .= '<dt>' . t('Tracker navigation') . '</dt>';
       $output .= '<dd>' . t('The Tracker module adds a new menu item to the Tools menu, called <em>Recent content</em>. You can configure menu items via the <a href="@menus">Menus administration page</a>.', array('@menus' => url('admin/structure/menu'))) . '</dd>';
       $output .= '<dt>' . t('Tracking new and updated site content') . '</dt>';
-      $output .= '<dd>' . t("The <a href='@recent'>Recent content</a> page shows new and updated content in reverse chronological order, listing the content type, title, author's name, number of comments, and time of last update. Content is considered updated when changes occur in the text, or when new comments are added. The <em>My recent content</em> tab limits the list to the currently logged-in user.", array('@recent' => url('tracker'))) . '</dd>';
+      $output .= '<dd>' . t("The <a href='@recent'>Recent content</a> page shows new and updated content in reverse chronological order, listing the content type, title, author's name, number of comments, and time of last update. Content is considered updated when changes occur in the text, or when new comments are added. The <em>My recent content</em> tab limits the list to the currently logged-in user.", array('@recent' => url('activity'))) . '</dd>';
       $output .= '<dt>' . t('Tracking user-specific content') . '</dt>';
-      $output .= '<dd>' . t("To follow a specific user's new and updated content, select the <em>Track</em> tab from the user's profile page.") . '</dd>';
+      $output .= '<dd>' . t("To follow a specific user's new and updated content, select the <em>Activity</em> tab from the user's profile page.") . '</dd>';
       $output .= '</dl>';
       return $output;
   }
diff --git a/core/modules/tracker/tracker.routing.yml b/core/modules/tracker/tracker.routing.yml
index 4de8d8f..c1788f8 100644
--- a/core/modules/tracker/tracker.routing.yml
+++ b/core/modules/tracker/tracker.routing.yml
@@ -1,5 +1,5 @@
 tracker.page:
-  path: '/tracker'
+  path: '/activity'
   defaults:
     _content: '\Drupal\tracker\Controller\TrackerPage::getContent'
     _title: 'Recent content'
@@ -7,7 +7,7 @@ tracker.page:
     _permission: 'access content'
 
 tracker.users_recent_content:
-  path: '/tracker/{user}'
+  path: '/activity/{user}'
   defaults:
     _content: '\Drupal\tracker\Controller\TrackerUserRecent::getContent'
     _title: 'My recent content'
@@ -18,7 +18,7 @@ tracker.users_recent_content:
     _access_tracker_own_information: 'TRUE'
 
 tracker.user_tab:
-  path: '/user/{user}/track'
+  path: '/user/{user}/activity'
   defaults:
     _content: '\Drupal\tracker\Controller\TrackerUserTab::getContent'
     _title_callback: '\Drupal\tracker\Controller\TrackerUserTab::getTitle'

diff --git a/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerNodeAccessTest.php b/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerNodeAccessTest.php
index 57828bf..4117bc2 100644
--- a/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerNodeAccessTest.php
+++ b/core/modules/tracker/lib/Drupal/tracker/Tests/TrackerNodeAccessTest.php
@@ -24,7 +24,7 @@ class TrackerNodeAccessTest extends WebTestBase {
   public static function getInfo() {
     return array(
       'name' => 'Tracker Node Access Tests',
-      'description' => 'Tests for private node access on /tracker.',
+      'description' => 'Tests for private node access on /activity.',
       'group' => 'Tracker',
     );
   }
@@ -37,7 +37,7 @@ public function setUp() {
   }
 
   /**
    * Ensure private node on /tracker is only visible to users with permission.
    */
   function testTrackerNodeAccess() {
     // Create user with node test view permission.
@@ -59,19 +59,19 @@ function testTrackerNodeAccess() {
     ));
 
     // User with access should see both nodes created.
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertText($private_node->getTitle(), 'Private node is visible to user with private access.');
     $this->assertText($public_node->getTitle(), 'Public node is visible to user with private access.');
-    $this->drupalGet('user/' . $access_user->id() . '/track');
+    $this->drupalGet('user/' . $access_user->id() . '/activity');
     $this->assertText($private_node->getTitle(), 'Private node is visible to user with private access.');
     $this->assertText($public_node->getTitle(), 'Public node is visible to user with private access.');
 
     // User without access should not see private node.
     $this->drupalLogin($no_access_user);
-    $this->drupalGet('tracker');
+    $this->drupalGet('activity');
     $this->assertNoText($private_node->getTitle(), 'Private node is not visible to user without private access.');
     $this->assertText($public_node->getTitle(), 'Public node is visible to user without private access.');
-    $this->drupalGet('user/' . $access_user->id() . '/track');
+    $this->drupalGet('user/' . $access_user->id() . '/activity');
     $this->assertNoText($private_node->getTitle(), 'Private node is not visible to user without private access.');
     $this->assertText($public_node->getTitle(), 'Public node is visible to user without private access.');
   }
@@ -37,7 +37,7 @@ public function setUp() {
 
   /**
-   * Ensure private node on /tracker is only visible to users with permission.
+   * Ensure private node on /activity is only visible to users with permission.
    */
   function testTrackerNodeAccess() {